==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Jag har läst licens avtalet och accepterat det"

, "License Agreement"
: "Licens Avtal"

, "I have read the privacy agreement and accept it"
: "jag har läst sekretess avtalet och accepterat det."

, "Privacy Agreement"
: "Sekretess Avtal"

, "Accept Terms and Conditions"
: "Acceptera Villkor"

, "Backend"
: "Backend"

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Hostname"
: "Host namn"

, "Username"
: "Användarnamn"

, "Password"
: "Lösenord"

, "Port"
: "port"

, "Secure Connection"
: "Säker Anslutning"

, "None"
: "Ingen"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Använd system konto"

, "No"
: "nej"

, "Yes"
: "Ja"

, "Append domain to login name"
: "Fäst domän till inloggnings namn"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Cyrus Administratör"

, "Cyrus Admin Password"
: "Cyrus Administratörs Lösenord"

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentisering"

, "Login"
: "Logga in"

, "Plain"
: "Vanlig"

, "Primary Domain"
: "Primär Domän"

, "Secondary Domains (comma separated)"
: "Sekundära Domäner (komma separerade)"

, "Notifications service address"
: "Meddelande service adress"

, "Notification Username"
: "Meddelande Användarnamn"

, "Notification Password"
: "Meddelande Lösenord"

, "Notifications local client (hostname or IP address)"
: "Meddelande lokal klient (hostname eller IP adress)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "Mysql Databas"

, "MySql User"
: "MySql Användare"

, "MySql Password"
: "MySql Lösenord"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "Användare eller UID"

, "Group or GID"
: "Grupp eller GID"

, "Home Template"
: "hem-mall"

, "Password Scheme"
: "Lösenord ordning"

, "PLAIN-MD5"
: "VANLIG-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "VANLIG"

, "Terms and Conditions"
: "Villkor"

, "Setup Checks"
: "Inställnings Kontroller"

, "Config Manager"
: "Config hanterare"

, "Authentication/Accounts"
: "Verifiering / konton"

, "Email"
: "E-post"

, "Application Manager"
: "Applikation Hanterare"

, "Setup"
: ""

, "Name"
: "Namn"

, "Enabled"
: "Aktiverad"

, "Order"
: "Order"

, "Installed Version"
: "Installerad Version"

, "Available Version"
: "Tillgänglig Version"

, "Status"
: "Status"

, "Depends on"
: "Beror på"

, "Install application"
: "Installera applikation"

, "Uninstall application"
: "Avinstallera applikation"

, "Update application"
: "Uppdatera applikation"

, "Go to {0} login"
: "Gå till {0} Logga in"

, "uninstall"
: "Avinstallera"

, "Do you really want to uninstall the application(s)?"
: "Vill du verkligen avinstallera programmet (n)?"

, "This may take a while"
: "Detta kan ta ett tag"

, "Dependency Violation"
: "Överträdelse"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "radera alla existerande användare och grupper"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Växla från SQL till LDAP kommer att ta bort alla befintliga användarkonton, grupper och roller. Vill du verkligen byta konto lagring backend till LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Första Administratörs Användare"

, "Initial admin login name"
: "Första administratörs användarnamn"

, "Initial admin Password"
: "Första administratörs Lösenord"

, "Password confirmation"
: "Lösenords konfirmation"

, "Authentication provider"
: "autentiserings leverantör"

, "Try to split username"
: "Försök att dela användarnamn"

, "Account canonical form"
: "Konto canonical form"

, "Account domain name"
: ""

, "Account domain short name"
: "Konto Domän kort namn"

, "Host"
: "Host"

, "Login name"
: "Inloggnins namn"

, "Bind requires DN"
: "Bind kräver DN"

, "Start TLS"
: ""

, "Base DN"
: "Bas DN"

, "Search filter"
: "Sök filter"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Konto lagring"

, "Default user group name"
: "Standard användare grupp namn"

, "Default admin group name"
: "Standard admin grupp namn"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Lösenordsinställningar"

, "User can change password"
: "Användare kan byta lösenord"

, "Enable password policy"
: "Aktivera lösenordspolicy"

, "Only ASCII"
: "Endast ASCII"

, "Minimum length"
: "Minst antal tecken"

, "Minimum word chars"
: "Minsta antal små bokstäver"

, "Minimum uppercase chars"
: "Minsta antal stora bokstäver"

, "Minimum special chars"
: "Minsta antal specialtecken"

, "Minimum numbers"
: "Minsta antal siffror"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Ändra Inställningar"

, "Redirect Url (redirect to login screen if empty)"
: "Ändra Url (Ändra till logga in sida om det är tomt)"

, "Redirect Always (if No, only redirect after logout)"
: "Ändra Alltid (om Nej, bara ändra efter utloggning)"

, "Redirect to referring site, if exists"
: "Ändra till hänvisnings sida, om en sådan existerar"

, "Password encoding"
: "Lösenord kodning"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Användar DN"

, "User Filter"
: "Användar Filter"

, "User Search Scope"
: "Användar Sök Fällt"

, "Groups DN"
: "Grupp DN"

, "Group Filter"
: "Grupp Filter"

, "Group Search Scope"
: "Grupp Sök Fällt"

, "Use Rfc 2307 bis"
: "Använd Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Minsta Användar Id"

, "Max User Id"
: "Max användar Id"

, "Min Group Id"
: "Minsta Grupp Id"

, "Max Group Id"
: "Max Grupp Id"

, "Group UUID Attribute name"
: "Grupp UUID Attributnamn"

, "User UUID Attribute name"
: "Användare UUID Attributnamn"

, "Readonly access"
: "Bara läsrättighet"

, "Save config and install"
: "Spara ändring och installera"

, "Save config"
: "Spara ändring"

, "Passwords don't match"
: "Lösenord matchar inte"

, "Should not be empty"
: "Ska inte vara tom"

, "Performing Environment Checks..."
: "Gör Omgivnings Kontroller..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Inga "

, "Check"
: "Kontrollera"

, "Result"
: "Resultat"

, "Error"
: "Fel"

, "Run setup tests"
: "Kör installations tester"

, "Ignore setup tests"
: "Ignorera installations tester"

, "Application, Applications"
: [
  "Applikation"
 ,"Applikationer"

]
, "File"
: "Fil"

, "Setup Authentication"
: "Inställnings Autentisering"

, "Database"
: "Databas"

, "User"
: "Användare"

, "Prefix"
: "Prefix"

, "Logging"
: "Loggar"

, "Filename"
: "Filnamn"

, "Priority"
: "Prioritet"

, "Caching"
: "Fångar"

, "Lifetime (seconds)"
: "Livstid (sekunder)"

, "Path"
: "Väg"

, "Queue"
: ""

, "Session"
: "Se"

, "Temporary files"
: "Temporära filer"

, "Temporary Files Path"
: "Temporära Fil Vägar"

, "Filestore directory"
: "Session"

, "Filestore Path"
: "Fillagrings väg"

, "Addressbook Map panel"
: "Adressboks karta"

, "Map panel"
: "Karta"

, "disabled"
: "Inaktiverad"

, "enabled"
: "Aktiverad"

, "Config file is not writable"
: "Config fil är inte skrivbar"

, "Download config file"
: "Ladda ner config fil"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Applikation"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-sv_SE-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Swedish (Sweden) (http://www.transifex.com/tine20/tine20/language/sv_SE/)\nLanguage: sv_SE\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Gör Omgivnings Kontroller..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Inga "

, "Check"
: "Kontrollera"

, "Result"
: "Resultat"

, "Message"
: ""

, "Run setup tests"
: "Kör installations tester"

, "Ignore setup tests"
: "Ignorera installations tester"

, "Install application"
: "Installera applikation"

, "Name"
: "Namn"

, "Enabled"
: "Aktiverad"

, "Order"
: "Order"

, "Installed Version"
: "Installerad Version"

, "Available Version"
: "Tillgänglig Version"

, "Status"
: "Status"

, "Depends on"
: "Beror på"

, "Uninstall application"
: "Avinstallera applikation"

, "Update applications"
: ""

, "Go to {0} login"
: "Gå till {0} Logga in"

, "uninstall"
: "Avinstallera"

, "Do you really want to uninstall the application(s)?"
: "Vill du verkligen avinstallera programmet (n)?"

, "This may take a while"
: "Detta kan ta ett tag"

, "Dependency Violation"
: "Överträdelse"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "radera alla existerande användare och grupper"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Växla från SQL till LDAP kommer att ta bort alla befintliga användarkonton, grupper och roller. Vill du verkligen byta konto lagring backend till LDAP?"

, "Backend"
: "Backend"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Första Administratörs Användare"

, "Initial admin login name"
: "Första administratörs användarnamn"

, "Initial admin Password"
: "Första administratörs Lösenord"

, "Password confirmation"
: "Lösenords konfirmation"

, "Authentication provider"
: "autentiserings leverantör"

, "Try to split username"
: "Försök att dela användarnamn"

, "Yes"
: "Ja"

, "No"
: "nej"

, "Account canonical form"
: "Konto canonical form"

, "Account domain name"
: ""

, "Account domain short name"
: "Konto Domän kort namn"

, "Host"
: "Host"

, "Login name"
: "Inloggnins namn"

, "Password"
: "Lösenord"

, "Bind requires DN"
: "Bind kräver DN"

, "Start TLS"
: ""

, "SSL"
: "SSL"

, "Port"
: "port"

, "Base DN"
: "Bas DN"

, "Search filter"
: "Sök filter"

, "Hostname"
: "Host namn"

, "Secure Connection"
: "Säker Anslutning"

, "None"
: "Ingen"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Fäst domän till inloggnings namn"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Konto lagring"

, "Default user group name"
: "Standard användare grupp namn"

, "Default admin group name"
: "Standard admin grupp namn"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: "Lösenordsinställningar"

, "User can change password"
: "Användare kan byta lösenord"

, "Enable password policy"
: "Aktivera lösenordspolicy"

, "Only ASCII"
: "Endast ASCII"

, "Minimum length"
: "Minst antal tecken"

, "Minimum word chars"
: "Minsta antal små bokstäver"

, "Minimum uppercase chars"
: "Minsta antal stora bokstäver"

, "Minimum special chars"
: "Minsta antal specialtecken"

, "Minimum numbers"
: "Minsta antal siffror"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Ändra Inställningar"

, "Redirect Url (redirect to login screen if empty)"
: "Ändra Url (Ändra till logga in sida om det är tomt)"

, "Redirect Always (if No, only redirect after logout)"
: "Ändra Alltid (om Nej, bara ändra efter utloggning)"

, "Redirect to referring site, if exists"
: "Ändra till hänvisnings sida, om en sådan existerar"

, "Password encoding"
: "Lösenord kodning"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Användar DN"

, "User Filter"
: "Användar Filter"

, "User Search Scope"
: "Användar Sök Fällt"

, "Groups DN"
: "Grupp DN"

, "Group Filter"
: "Grupp Filter"

, "Group Search Scope"
: "Grupp Sök Fällt"

, "Use Rfc 2307 bis"
: "Använd Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Minsta Användar Id"

, "Max User Id"
: "Max användar Id"

, "Min Group Id"
: "Minsta Grupp Id"

, "Max Group Id"
: "Max Grupp Id"

, "Group UUID Attribute name"
: "Grupp UUID Attributnamn"

, "User UUID Attribute name"
: "Användare UUID Attributnamn"

, "Readonly access"
: "Bara läsrättighet"

, "Save config and install"
: "Spara ändring och installera"

, "Save config"
: "Spara ändring"

, "Passwords don't match"
: "Lösenord matchar inte"

, "Should not be empty"
: "Ska inte vara tom"

, "File"
: "Fil"

, "Setup Authentication"
: "Inställnings Autentisering"

, "Username"
: "Användarnamn"

, "Database"
: "Databas"

, "User"
: "Användare"

, "Prefix"
: "Prefix"

, "Logging"
: "Loggar"

, "Filename"
: "Filnamn"

, "Priority"
: "Prioritet"

, "Caching"
: "Fångar"

, "Lifetime (seconds)"
: "Livstid (sekunder)"

, "Path"
: "Väg"

, "Queue"
: ""

, "Session"
: "Se"

, "Temporary files"
: "Temporära filer"

, "Temporary Files Path"
: "Temporära Fil Vägar"

, "Filestore directory"
: "Session"

, "Filestore Path"
: "Fillagrings väg"

, "Addressbook Map panel"
: "Adressboks karta"

, "Map panel"
: "Karta"

, "disabled"
: "Inaktiverad"

, "enabled"
: "Aktiverad"

, "Config file is not writable"
: "Config fil är inte skrivbar"

, "Download config file"
: "Ladda ner config fil"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard SMTP"

, "Imap"
: "Imap"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Använd system konto"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Cyrus Administratör"

, "Cyrus Admin Password"
: "Cyrus Administratörs Lösenord"

, "Use proxy auth"
: ""

, "Smtp"
: "Smtp"

, "Authentication"
: "Autentisering"

, "Login"
: "Logga in"

, "Plain"
: "Vanlig"

, "Primary Domain"
: "Primär Domän"

, "Secondary Domains (comma separated)"
: "Sekundära Domäner (komma separerade)"

, "Notifications service address"
: "Meddelande service adress"

, "Notification Username"
: "Meddelande Användarnamn"

, "Notification Password"
: "Meddelande Lösenord"

, "Notifications local client (hostname or IP address)"
: "Meddelande lokal klient (hostname eller IP adress)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "Mysql Databas"

, "MySql User"
: "MySql Användare"

, "MySql Password"
: "MySql Lösenord"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "Användare eller UID"

, "Group or GID"
: "Grupp eller GID"

, "Home Template"
: "hem-mall"

, "Password Scheme"
: "Lösenord ordning"

, "PLAIN-MD5"
: "VANLIG-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "VANLIG"

, "Setup"
: ""

, "Application, Applications"
: [
  "Applikation"
 ,"Applikationer"

]
, "Terms and Conditions"
: "Villkor"

, "Setup Checks"
: "Inställnings Kontroller"

, "Config Manager"
: "Config hanterare"

, "Authentication/Accounts"
: "Verifiering / konton"

, "Email"
: "E-post"

, "Application Manager"
: "Applikation Hanterare"

, "I have read the license agreement and accept it"
: "Jag har läst licens avtalet och accepterat det"

, "License Agreement"
: "Licens Avtal"

, "I have read the privacy agreement and accept it"
: "jag har läst sekretess avtalet och accepterat det."

, "Privacy Agreement"
: "Sekretess Avtal"

, "Accept Terms and Conditions"
: "Acceptera Villkor"


, "Application"
: "Applikation"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
